<?php

define("SENDER_EMAIL", "ruzinov@bighuggym.sk");

class PaymentsController extends Controller {

    /**
     * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
     * using two-column layout. See 'protected/views/layouts/column2.php'.
     */
    public $layout = '//layouts/column2';

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array(''),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array(''),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('admin', 'delete', 'index', 'view', 'create', 'confirm', 'update', 'generatePayment', 'confirmPayment', 'confirmAnyPayment', 'pregeneratePayment', 'sendAndConfirm'),
                'users' => array('admin.ruz@bighuggym.com'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Displays a particular model.
     * @param integer $id the ID of the model to be displayed
     */
    public function actionView($id) {
        $this->render('view', array(
            'model' => $this->loadModel($id),
        ));
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     */
    public function actionCreate() {
        $model = new Payments;

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Payments'])) {
            $model->attributes = $_POST['Payments'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('create', array(
            'model' => $model,
        ));
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     * @param integer $id the ID of the model to be updated
     */
    public function actionUpdate($id) {
        $model = $this->loadModel($id);

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Payments'])) {
            $model->attributes = $_POST['Payments'];
            if ($model->save())
                $this->redirect(array('view', 'id' => $model->ID));
        }

        $this->render('update', array(
            'model' => $model,
        ));
    }

    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'admin' page.
     * @param integer $id the ID of the model to be deleted
     */
    public function actionDelete($id) {
        $this->loadModel($id)->delete();

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
    }

    /**
     * Lists all models.
     */
    public function actionIndex() {
        $dataProvider = new CActiveDataProvider('Payments');
        $this->render('index', array(
            'dataProvider' => $dataProvider,
        ));
    }

    /**
     * Manages all models.
     */
    public function actionAdmin() {
        $model = new Payments('search');
        $model->unsetAttributes();  // clear any default values
        if (isset($_GET['Payments'])) {
            $model->attributes = $_GET['Payments'];
        }
        Yii::app()->user->setState('grid',$_GET);
        $this->render('admin', array(
            'model' => $model,
        ));
    }

    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     * @param integer $id the ID of the model to be loaded
     * @return Payments the loaded model
     * @throws CHttpException
     */
    public function loadModel($id) {
        $model = Payments::model()->findByPk($id);
        if ($model === null)
            throw new CHttpException(404, 'The requested page does not exist.');
        return $model;
    }

    /**
     * Performs the AJAX validation.
     * @param Payments $model the model to be validated
     */
    protected function performAjaxValidation($model) {
        if (isset($_POST['ajax']) && $_POST['ajax'] === 'payments-form') {
            echo CActiveForm::validate($model);
            Yii::app()->end();
        }
    }

    public function actionGeneratePayment() {
        $model = new Payments();

        $data = Users::model()->with('kids')->findAllByAttributes(array(
            'rights_ID' => '2',
                ), array(
            'order' => 'kids.surname ASC'
        ));
        //$kids = Kids::model()->with('payments')->findAll();
        //for which child/parent
        $semesters = Semesters::model()->findAll();
        //for semester
        //var symb?

        if (isset($_POST['kidID'])) {
            //generuj paymanet
            $thiskid = Kids::model()->findByPk($_POST['kidID']);

            $par = Users::model()->findByPk($thiskid->parrent_ID);


            $model->ID_kid = $_POST['kidID'];
            $model->date = date('Y-m-d');

            $holiday = Holiday::model()->findAll();
            //obsahuje datumy vsetkych prazdnin
            $hol_array = array();

            foreach ($holiday as $hd) {
                $date_ = $hd->date_start;
                $end_date_ = $hd->date_end;

                while (strtotime($date_) <= strtotime($end_date_)) {
                    $hol_array[] = $date_;
                    $date_ = date("Y-m-d", strtotime("+1 day", strtotime($date_)));
                }
            }

            $cursemid = '';

            // treba zobrat vsetky enlisty
            $enlkid = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
                'ID_kid' => $thiskid->ID,
            ));
            // zistit aky to je den
            foreach ($enlkid as $key) {
                $enlday[] = (int) $key->iDTimet->week_day;
            }

            // prechadzat nasledujucimi tyzdnami az po koniec semestra
            // ak tam nie ju sprazdniny, pripocitat.



            if ($_POST['specif'] == 'forSemester') {
                $thissem = Semesters::model()->findByPk($_POST['semID']);

                $model->trimester = $_POST['semID'];
                $date = $thissem->date_start;
                $end_date = $thissem->date_end;
            } elseif ($_POST['specif'] == 'forDate') {
                $cursem = Semesters::model()->findAll();
                foreach ($cursem as $sm) {

                    $semdate = $sm->date_start;
                    $end_date = $sm->date_end;

                    while (strtotime($semdate) < strtotime($end_date)) {

                        if ($semdate == date('Y-m-d')) {
                            $cursemid = $sm->ID;
                        }
                        $semdate = date('Y-m-d', strtotime("+1 day", strtotime($semdate)));
                    }
                }
                $model->trimester = $cursemid;
                $date = $_POST['d']['begin'];
                //date('Y-m-d', strtotime("+8 day", strtotime($date)));
                $end_date = $_POST['d']['end'];
            }


            $c = 0;
            //pre semester = od zaciatku semestra, po koniec


            while (strtotime($date) < strtotime($end_date)) {
                if (in_array(date('N', strtotime($date)), $enlday)) {
                    if (!(in_array($date, $hol_array))) {
                        $iter = array_count_values($enlday);
                        $c += $iter[date('N', strtotime($date))];
                    }
                }
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }



            $model->n_of_hours = $c; //vypocitat.


            if ($thiskid->frequency == 2) {
                $model->prize_per_h = 8;
            } else {
                $model->prize_per_h = 10;
            }


            $model->discount = $_POST['discount']; //v zavislosti od mnzostva deti

            $model->payed = 0;

            $model->VS = '0000000000';
            //10 znakov netusim ako generovat;
            if ($model->validate()) {
                $model->save();
                $model->VS = $model->ID;
                $model->save();
                //print_r($model);
                //print_r($_POST);
                //vygeneruj hodiny? !
                if (isset($_POST['generate_hours'])) {
                    if ($_POST['generate_hours'] == 'yes') {

                        if ($_POST['specif'] == 'forSemester') {
                            Yii::app()->helper->generateHours($_POST['kidID'], $thissem->date_start, $thissem->date_end);
                        } elseif ($_POST['specif'] == 'forDate') {
                            Yii::app()->helper->generateHours($_POST['kidID'], $_POST['d']['begin'], $_POST['d']['end']);
                        }
                    }
                }

                if (isset($_POST['send_mail'])) {
                    if ($_POST['send_mail'] == 'yes') {


                        if ($_POST['specif'] == 'forSemester') {
                            $cursem = $thissem;
                        } elseif ($_POST['specif'] == 'forDate') {
                            $cursem = Semesters::model()->findByPk($cursemid);
                        }

                        $sum = $model->prize_per_h * $model->n_of_hours;
                        $fsum = (float) $sum * (( 100 - $model->discount ) / 100);

                        $mailbody = '
<html>
<head></head>
<body>

  Ďakujeme za Váš záujem o využívanie našich služieb.<br />
  <br />
  V tomto emaile si Vám dovoľujeme zaslať detailné údaje potrebné k realizácii platby za Vaše dieťa:<br />
  <br />
  ' . $thiskid->name . ' ' . $thiskid->surname . '<br />
  Kurz: ' . $thiskid->lesson . '<br />
  Trimester:  ' . $cursem->label . '<br />
  <br />
  ////////////////////////////////////////////////////////////////////////////// <br />
  Počet hodín:          ' . $model->n_of_hours . ' na trimester <br />
  Suma za hod.:         ' . $model->prize_per_h . ' EUR <br />
  Celková suma:         ' . $sum . ' EUR <br />
  Zľava:                ' . $model->discount . ' % <br />
  Suma na zaplatenie:   ' . $fsum . ' EUR <br />
  ////////////////////////////////////////////////////////////////////////////// <br />
  <br />
  Uvedenú sumu prosím uhraďte prevodom na náš bankový účet do siedmich dní od dátumu doručenia tohto emailu.<br />
  <br />
  Číslo účtu BigHugGym:	' . $_POST['account'] . ' <br />
  Variabilný symbol:    ' . $model->VS . ' <br />
  <br />
  Do komentára k transakcii dopíšte aj meno a priezvisko Vášho dietaťa pre jednoduchšiu identifikáciu. <br />
  <br />
  Ďakujeme.<br />
  Vážime si, že využívate naše služby.<br />
  <br />
  S pozdravom <br />
  Váš tím BigHugGym <br />

</body>
</html>
';

                        $headers = 'MIME-Version: 1.0' . "\r\n";
                        $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
                        $headers .= 'From: ' . SENDER_EMAIL . "\r\n";
                        $headers .= 'Reply-To: ' . SENDER_EMAIL . "\r\n";

                        $rcpt = $par->email;
                        $subj = 'BigHugGym – výzva na zaplatenie';


                        if (mail($rcpt, $subj, $mailbody, $headers)) {
                            mail('kontrola.ruzinov@bighuggym.sk','ZALOHA: '.$subj, $mailbody, $headers);
                            $this->redirect(array('payments/index'));
                        }
                    }
                }
            }
        }


        $this->render('generatePayment', array(
            'model' => $model,
            'data' => $data,
            'semesters' => $semesters,
                //'kids' => $kids,
        ));
    }

//NEW //////////////////////////////////////////////////////////////////////////

    public function actionPregeneratePayment() {
        $model = new Payments();

        $data = Users::model()->with('kids')->findAllByAttributes(array(
            'rights_ID' => '2',
                ), array(
            'order' => 'kids.surname ASC'
        ));


        $kids = Kids::model()->findAll(array('order'=>'surname'));
        //for which child/parent
        $semesters = Semesters::model()->findAll(array('order'=>'ID DESC'));
        //for semester
        //var symb?

        if (isset($_POST['kidID'])) {

            $thedata = array();
            $thedata['post'] = $_POST;
            //generuj paymanet
            $thiskid = Kids::model()->findByPk($_POST['kidID']);

            $par = Users::model()->findByPk($thiskid->parrent_ID);


            $thedata['payment']['ID_kid'] = $_POST['kidID'];
            $model->ID_kid = $_POST['kidID'];
            $thedata['payment']['date'] = date('Y-m-d');
            $model->date = date('Y-m-d');

            $holiday = Holiday::model()->findAll();
            //obsahuje datumy vsetkych prazdnin
            $hol_array = array();

            foreach ($holiday as $hd) {
                $date_ = $hd->date_start;
                $end_date_ = $hd->date_end;

                while (strtotime($date_) <= strtotime($end_date_)) {
                    $hol_array[] = $date_;
                    $date_ = date("Y-m-d", strtotime("+1 day", strtotime($date_)));
                }
            }

            $cursemid = '';

            // treba zobrat vsetky enlisty
            $enlkid = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
                'ID_kid' => $thiskid->ID,
            ));
            // zistit aky to je den
            foreach ($enlkid as $key) {
                $enlday[] = (int) $key->iDTimet->week_day;
            }

            // prechadzat nasledujucimi tyzdnami az po koniec semestra
            // ak tam nie ju sprazdniny, pripocitat.



            if ($_POST['specif'] == 'forSemester') {
                $thissem = Semesters::model()->findByPk($_POST['semID']);

                $thedata['payment']['trimester'] = $_POST['semID'];
                $model->trimester = $_POST['semID'];
                $date = $thissem->date_start;
                $end_date = $thissem->date_end;
            } elseif ($_POST['specif'] == 'forDate') {
                $cursem = Semesters::model()->findAll();
                foreach ($cursem as $sm) {

                    $semdate = $sm->date_start;
                    $end_date = $sm->date_end;

                    while (strtotime($semdate) <= strtotime($end_date)) {

                        if ($semdate == date('Y-m-d')) {
                            $cursemid = $sm->ID;
                        }
                        $semdate = date('Y-m-d', strtotime("+1 day", strtotime($semdate)));
                    }
                }
                $thedata['payment']['trimester'] = $cursemid;
                $model->trimester = $cursemid;
                $date = $_POST['d']['begin'];
                //date('Y-m-d', strtotime("+8 day", strtotime($date)));
                $end_date = $_POST['d']['end'];
            }


            $c = 0;
            //pre semester = od zaciatku semestra, po koniec
            $debug = array();

            while (strtotime($date) <= strtotime($end_date)) {
                if (in_array(date('N', strtotime($date)), $enlday)) {
                    if (!(in_array($date, $hol_array))) {
                        $iter = array_count_values($enlday);
                        $c += $iter[date('N', strtotime($date))];
                        $debug[] = date('d-m-Y', strtotime($date));
                    }
                }
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }


            $thedata['payment']['n_of_hours'] = $c;
            $model->n_of_hours = $c; //vypocitat.


            if ($thiskid->frequency == 2) {
                $model->prize_per_h = 8;
                $thedata['payment']['prize_per_h'] = 8;
            } else {
                $model->prize_per_h = 10;
                $thedata['payment']['prize_per_h'] = 10;
            }

            $thedata['payment']['discount'] = 0;
            $model->discount = 0; //v zavislosti od mnzostva deti
            $thedata['payment']['payed'] = 0;
            $model->payed = 0;

            $thedata['payment']['VS'] = '0000000000';
            $model->VS = '0000000000';
            //10 znakov netusim ako generovat;
            if ($model->validate()) {
                //$thedata['payment'] = $model;
                //$model->save();
                //$model->VS = $model->ID;
                //$model->save();
                //print_r($model);
                //print_r($_POST);
                //vygeneruj hodiny? !

                /*
                  if (isset($_POST['generate_hours'])) {
                  if ($_POST['generate_hours'] == 'yes') {
                 */
                /*
                  if ($_POST['specif'] == 'forSemester') {
                  Yii::app()->helper->generateHours($_POST['kidID'], $thissem->date_start, $thissem->date_end);
                  } elseif ($_POST['specif'] == 'forDate') {
                  Yii::app()->helper->generateHours($_POST['kidID'], $_POST['d']['begin'], $_POST['d']['end']);
                  }
                 */
                if ($_POST['specif'] == 'forSemester') {
                    $thedata['start_date'] = $thissem->date_start;
                    $thedata['end_date'] = $thissem->date_end;
                } elseif ($_POST['specif'] == 'forDate') {
                    $thedata['start_date'] = $_POST['d']['begin'];
                    $thedata['end_date'] = $_POST['d']['end'];
                }
                /*
                  }
                  }
                 */



                if ($_POST['specif'] == 'forSemester') {
                    $cursem = $thissem;
                } elseif ($_POST['specif'] == 'forDate') {
                    $cursem = Semesters::model()->findByPk($cursemid);
                }

                $sum = $model->prize_per_h * $model->n_of_hours;
                $fsum = (float) $sum * (( 100 - $model->discount ) / 100);


                if (($thiskid->lesson == 1) || ($thiskid->lesson == 2) || ($thiskid->lesson == 9)) {
                    $ucet = 'SK7802000000003204308959';
                    $thedata['ucet'] = 'SK7802000000003204308959';
                    //pre S.R.O. - SK7802000000003204308959
                    //pre OZ - SK3802000000003528888654
                } else {
                    $thedata['ucet'] = 'SK3802000000003528888654';
                    $ucet = 'SK3802000000003528888654';
                }


                $msgtop = '
<html>
<head></head>
<body>

  Ďakujeme za Váš záujem o využívanie našich služieb.<br />
  <br />
  V tomto emaile si Vám dovoľujeme zaslať detailné údaje potrebné k realizácii platby za Vaše dieťa:<br />
  <br />
  ' . $thiskid->name . ' ' . $thiskid->surname . '<br />

  Trimester:  ' . $cursem->label . '<br />
  <br />
  ////////////////////////////////////////////////////////////////////////////// <br />
  ';
                /*
                  Počet hodín:          ' . $model->n_of_hours . ' na trimester <br />
                  Suma za hod.:         ' . $model->prize_per_h . ' EUR <br />
                  Celková suma:         ' . $sum . ' EUR <br />
                  Zľava:                ' . $model->discount . ' % <br />
                  Suma na zaplatenie:   ' . $fsum . ' EUR <br />
                 */
                $msgbot = '
  ////////////////////////////////////////////////////////////////////////////// <br />
  <br />
  Uvedenú sumu prosím uhraďte prevodom na náš bankový účet do siedmich dní od dátumu doručenia tohto emailu.<br />
  <br />
  Číslo účtu BigHugGym:	' . $ucet . ' <br />
  Variabilný symbol:    ' . $model->VS . ' <br />
  <br />
  Do komentára k transakcii dopíšte aj meno a priezvisko Vášho dietaťa pre jednoduchšiu identifikáciu. <br />
  <br />
  Ďakujeme.<br />
  Vážime si, že využívate naše služby.<br />
  <br />
  S pozdravom <br />
  Váš tím BigHugGym <br />

';

                $headers = 'MIME-Version: 1.0' . "\r\n";
                $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
                $headers .= 'From: ' . SENDER_EMAIL . "\r\n";
                $headers .= 'Reply-To: ' . SENDER_EMAIL . "\r\n";

                $rcpt = $par->email;
                $subj = 'Platba za ' . $cursem->label;

                $thedata['mail']['texttop'] = $msgtop;
                $thedata['mail']['textbot'] = $msgbot;
                $thedata['mail']['recipient'] = $rcpt;
                $thedata['mail']['subject'] = $subj;
                $thedata['mail']['headers'] = $headers;

                /*
                  if (mail($rcpt, $subj, $mailbody, $headers)) {
                  $this->redirect(array('payments/index'));
                  //$this->redirect(array('payments/showBeforeSend', ));
                  //$this->render('showBeforeSend', );
                  } */
            }
        }
        /*    }

          } */

        if (isset($_POST['kidID'])) {
            $this->render('showPregenerated', array(
                'old' => $thedata,
                'c' => $debug
            ));
        } else {
            $this->render('pregeneratePayment', array(
                'model' => $model,
                'data' => $data,
                'semesters' => $semesters,
                'kids' => $kids,
            ));
        }
    }

    public function actionSendAndConfirm() {
        $model = new Payments('genPayments');
        $model->ID_kid = $_POST['ID_kid'];
        $model->date = $_POST['date'];
        $model->discount = $_POST['discount'];
        $model->n_of_hours = $_POST['n_of_hours'];
        $model->payed = 0;
        $model->trimester = $_POST['trimester'];
        $model->prize_per_h = $_POST['prize_per_h'];
        $model->VS = '0000000000';
        if ($model->validate()) {
            $model->save();
            $model->VS = "100".$model->ID;
            $model->save();
        }

        if (isset($_POST['odoslat'])) {
            if (isset($_POST['send_mail'])) {
                if (($_POST['send_mail']) == 'yes') {
                    $headers = 'MIME-Version: 1.0' . "\r\n";
                    $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
                    $headers .= 'From: ' . SENDER_EMAIL . "\r\n";
                    $headers .= 'Reply-To: ' . SENDER_EMAIL . "\r\n";

                    $discoutned = '';
                    if ($model->discount != 0) {
                        $discoutned = '
                        Celková suma:         ' . $_POST['sum'] . ' EUR <br />
                        Zľava:                ' . $model->discount . ' % <br />';
                    }

                    $msgmid = '
                        Počet hodín:          ' . $model->n_of_hours . ' na trimester <br />
                        Suma za hod.:         ' . $model->prize_per_h . ' EUR <br />
                        ' . $discoutned . '
                        Suma na zaplatenie:   ' . $_POST['final'] . ' EUR <br />
                    ';

                    $var_sym = 'Variabilný symbol:    ' . $model->VS . ' <br />';
                    $bot = str_replace('Variabilný symbol:    0000000000 <br />', $var_sym, $_POST['email_part_bot']);

                    $body = $_POST['email_part_top'] . $msgmid . $bot . "</body></html>";

                    mail($_POST['email_addr'], $_POST['email_subj'], $body, $headers);
                    // mail('pales.michael@gmail.com', $_POST['email_subj'], $body, $headers);
                    mail('kontrola.ruzinov@bighuggym.sk','ZALOHA: '. $_POST['email_subj'], $body, $headers);
                    // mail('pales.michael@gmail.com','ZALOHA: '. $_POST['email_subj'], $body, $headers);
                }
            }
            if (isset($_POST['gen_hours'])) {
                if (($_POST['gen_hours']) == 'yes') {
                    Yii::app()->helper->generateHours($_POST['ID_kid'], $_POST['start_date'], $_POST['end_date']);
                }
            }

            $this->redirect(array('payments/admin'));
        }
    }

//NEW END //////////////////////////////////////////////////////////////////////

    public function actionConfirmAnyPayment() {
        $model = new Payments();

        $data = Users::model()->with('kids')->findAllByAttributes(array(
            'rights_ID' => '2',
                ), array(
            'order' => 't.surname ASC'
        ));
        //$kids = Kids::model()->with('payments')->findAll();
        //for which child/parent
        $semesters = Semesters::model()->findAll();
        //for semester
        //var symb?
        //cur semester
        $cursemid = '';
        $cursem = Semesters::model()->findAll();
        foreach ($cursem as $sm) {

            $date = $sm->date_start;
            //date('Y-m-d', strtotime("+8 day", strtotime($date)));
            $end_date = $sm->date_end;


            while (strtotime($date) < strtotime($end_date)) {

                if ($date == date('Y-m-d')) {
                    $cursemid = $sm->ID;
                }
                $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            }
        }

        $pay = Payments::model()->with('kid', 'trimester_')->findAllByAttributes(array(
            'trimester' => $cursemid,
                ), array('order' => 'date DESC')
        );

        //print_r($this);
        $this->render('confirmAnyPayment', array(
            'model' => $model,
            'data' => $data,
            'semesters' => $semesters,
            'payments' => $pay,
                //'kids' => $kids,
        ));
    }

    public function actionConfirmPayment($id) {
        $model = Payments::model()->findByPk($id);

        $model->payed = 1;

        $model->save();

        $kid = Kids::model()->with('parrent')->findByPk($model->ID_kid);
        $trimester = Semesters::model()->findByPk($model->trimester);

        //poslat mail
        $headers = 'MIME-Version: 1.0' . "\r\n";
        $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
        $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
        $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";

        $message = '
    <html>
    <head>
       <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
       <title>Potvrdenie platby</title>
    </head>
    <body>
      Vážený pán/pani ' . $kid->parrent->surname . '.<br />
      <br />
      Ďakujeme, práve sme zaregistrovali Vašu platbu za dieťa ' . $kid->name . ' ' . $kid->surname . ' na trimester ' . $trimester->label . ' . <br />
      <br />
      Ďakujeme.<br />
      Vážime si, že využívate naše služby.<br />
      <br />
      S pozdravom <br />
      Váš tím BigHugGym
    </body>
    </html>
    ';

        mail($kid->parrent->email, 'Platba BigHugGym', $message, $headers);
        mail('kontrola.ruzinov@bighuggym.sk','ZALOHA: Platba BigHugGym', $message, $headers);

        $this->redirect(array('confirmAnyPayment'));
    }

    public function actionConfirm($id) {
        $model = $this->loadModel($id);
        $model->payed = 1;
        $model->save();
        $kid = Kids::model()->findByPk($model->ID_kid);
            $kid->active = 1;
            $kid->save();
        $user = Users::model()->findByPk($kid->parrent_ID);

            $headers = 'MIME-Version: 1.0' . "\r\n";
            $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
            $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
            $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";

        $trimester = Semesters::model()->findByPk($model->trimester);

        $message_payed = '
        <html>
        <head>
           <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
           <title>Potvrdenie platby</title>
        </head>
        <body>
          Vážený pán/pani ' . $user->surname . '.<br />
          <br />
          Ďakujeme, práve sme zaregistrovali Vašu platbu za dieťa ' . $kid->name . ' ' . $kid->surname . ' na trimester ' . $trimester->label . ' . <br />
          <br />
          Ďakujeme.<br />
          Vážime si, že využívate naše služby.<br />
          <br />
          S pozdravom <br />
          Váš tím BigHugGym
        </body>
        </html>
        ';

        mail($user->email, 'Platba BigHugGym', $message_payed, $headers);
//        mail('pales.michael@gmail.com', 'Platba BigHugGym', $message_payed, $headers);

        if($user->active == 0){

            $md5Hash = md5(microtime());
            $mt = substr($md5Hash, 0, 8);
            $user->secure_hash = $mt;
            $user->password = hash('sha256', $mt);
            $user->active = 1;
            $user->passsent = 1;
            $user->save();

            $message_reg = '
            <html>
            <head>
               <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
               <title>email</title>
            </head>
            <body>
              Vážený pán/pani ' . $user->surname . '.<br />
              <br />
              Ďakujeme Vám za prejavený záujem o naše služby. Nižšie uvádzame Vaše prihlasovacie údaje do Vášho účtu v našom systéme ' . $_SERVER['SERVER_NAME'] . '/admin . Tento účet okrem iného slúži na odhlasovanie z hodín v prípade Vašej neúčasti a nahlasovanie náhradných hodín. Prosíme Vás, aby ste si po prvom prihlásení zmenili heslo.<br />
              <br />
              <strong>Meno:</strong> ' . $user->email . '<br />
              <strong>Heslo:</strong> ' . $user->secure_hash . '<br />
              <br />
              <strong>V prípade každej neúčasti na cvičení, Vás prosíme o odhlásenie z hodiny na základe Vášich prihlasovacíh údajov - emailu a hesla. Systém nám tak umožní vami vzniknutý nárok na náhradnú hodinu evidovať a Vám si prehľadne nájsť miesto (náhradnú hodinu) za absenciu.</strong><br />
              <br />
              Odhlásiť sa z hodiny je možné vždy deň vopred do 18:00. Náhradnú hodinu si môžete vybrať z ponuky najbližších 7 dní. Počet náhradných hodín, na ktoré máte nárok uvidíte po prihlásení.<br />
              <br />
              Ďakujeme.<br />
              <br />
              S pozdravom
              Váš tím BigHugGym
            </body>
            </html>
            ';


            mail($user->email, 'Prihlasovacie údaje pre portál bighuggym', $message_reg, $headers);
//            mail('pales.michael@gmail.com', 'Prihlasovacie údaje pre portál bighuggym', $message_reg, $headers);
        }

        if (Yii::app()->user->hasState('grid')) {
            $grid = Yii::app()->user->getState('grid');
            $route = array("payments/admin");
            Yii::app()->user->setState("grid", null);
            $this->redirect(array_merge($route, $grid));
            //echo CHtml::link("Return to Grid",array_merge($route,$grid));
        } else {
            $this->redirect(Yii::app()->user->returnUrl);
        }
    }

}
