<?php

class TrainerController extends Controller {

    public function init() {
        Yii::app()->errorHandler->errorAction = 'trainer/error';
    }

    /**
     * Declares class-based actions.
     */
    public $layout = '//layouts/trainer';

    public function actions() {
        return array(
            // captcha action renders the CAPTCHA image displayed on the contact page
            'captcha' => array(
                'class' => 'CCaptchaAction',
                'backColor' => 0xFFFFFF,
            ),
            // page action renders "static" pages stored under 'protected/views/site/pages'
            // They can be accessed via: index.php?r=site/page&view=FileName
            'page' => array(
                'class' => 'CViewAction',
            ),
        );
    }

    /**
     * @return array action filters
     */
    public function filters() {
        return array(
            'accessControl', // perform access control for CRUD operations
            'postOnly + delete', // we only allow deletion via POST request
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     * @return array access control rules
     */
    public function accessRules() {
        return array(
            array('allow', // allow all users to perform 'index' and 'view' actions
                'actions' => array(''),
                'users' => array('*'),
            ),
            array('allow', // allow authenticated user to perform 'create' and 'update' actions
                'actions' => array(''),
                'users' => array('@'),
            ),
            array('allow', // allow admin user to perform 'admin' and 'delete' actions
                'actions' => array('index', 'error', 'contact', 'TNovyTrim','TPokracovanie','TNepokracovanie','TNovyQuery', 'mojRozvrh', 'showHour', 'userProfile' ,'zobrazPotvrdenie', 'zobrazKlientov', 'pomoc', 'mojeUdaje', 'zobrazDeti', 'zobrazRodicov', 'user', 'dieta', 'zobrazText', 'celyRozvrh', 'showHourtrainer'),
                //'users'=>array('admin'),
                'expression' => array('TrainerController', 'allowOnlyOwner')
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Allow only the owner to do the action
     * @return boolean whether or not the user is the owner
     */
    public static function allowOnlyOwner() {
        if (isset(Yii::app()->user->userRightsId)) {
            if (Yii::app()->user->userRightsId == '3') {
                return true;
            }
        } else {
            return false;
        }
    }

    /**
     * This is the default 'index' action that is invoked
     * when an action is not explicitly requested by users.
     */
    /* public function actionIndex()
      {
      // renders the view file 'protected/views/site/index.php'
      // using the default layout 'protected/views/layouts/main.php'
      $this->render('index');
      } */

    public function actionIndex() {
        $this->layout = '//layouts/trainer';
        $this->render('index');
    }

    /**
     * This is the action to handle external exceptions.
     */
    public function actionError() {
        if ($error = Yii::app()->errorHandler->error) {
            if (Yii::app()->request->isAjaxRequest)
                echo $error['message'];
            else
                $this->render('error', $error);
        }
    }

    /**
     * Displays the contact page
     */
    public function actionContact() {
        $this->layout = '//layouts/trainer';
        $model = new ContactForm;
        if (isset($_POST['ContactForm'])) {
            $model->attributes = $_POST['ContactForm'];
            if ($model->validate()) {
                $name = '=?UTF-8?B?' . base64_encode($model->name) . '?=';
                $subject = '=?UTF-8?B?' . base64_encode($model->subject) . '?=';
                $headers = "From: $name <{$model->email}>\r\n" .
                        "Reply-To: {$model->email}\r\n" .
                        "MIME-Version: 1.0\r\n" .
                        "Content-Type: text/plain; charset=UTF-8";

                mail(Yii::app()->params['adminEmail'], $subject, $model->body, $headers);
                Yii::app()->user->setFlash('contact', 'Thank you for contacting us. We will respond to you as soon as possible.');
                $this->refresh();
            }
        }
        $this->render('contact', array('model' => $model));
    }

    /* ____________________________________________________________________________ */

    public function actionMojRozvrh() {
        $this->layout = '//layouts/trainer';

        date_default_timezone_set('CET');
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        $data = array();

        $c = 0;
        $i = date('N') - 1;
        $date = date('Y-m-d');
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($date)));


        while (strtotime($date) < strtotime($end_date)) {
            $data[$i] = Hours::model()->findAllByAttributes(array(
                'date' => $date,
            ));

            foreach ($data[$i] as $single) {
                $data[$i]['hours'][] = $single->time_start;
                $c++;
                $IDees[] = $single->ID;
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }

        for ($j = 0; $j < 7; $j++) {
            if (!(isset($data[$j]))) {
                $data[$j] = array();
            }
        }


        $this->render('mojrozvrh', array('thisWeek' => $data));
    }

    public function actionCelyRozvrh($for) {

        date_default_timezone_set('CET');
        //$curU = Users::model()->findByPk(Yii::app()->user->getId());

        $data = array();


        $i = 0;
        $date = date('Y-m-d', strtotime($for));

        while (date('N', strtotime($date)) != '1') {
            $date = date('Y-m-d', strtotime("-1 day", strtotime($date)));
        }

        $start_date = $date;
        $end_date = date('Y-m-d', strtotime("+7 day", strtotime($start_date)));


        while (strtotime($date) < strtotime($end_date)) {
            $data[$i] = Hours::model()->findAllByAttributes(array(
                'date' => $date,
            ));

            /*
              $data[$i]['timet'][] = Timetable::model()->with(array('trainer0'))->findAllByAttributes(array(
              'week_day' => $data[$i]->week_day,
              'time_start' => $data[$i]->time_start,
              'lesson' => $data[$i]->lesson
              ));
             */
            $timet = Timetable::model()->with(array('trainer0'))->findAllByAttributes(array(
                'active' => 1,
            ));

            foreach ($data[$i] as $single) {
                $data[$i]['hours'][] = $single->time_start;
            }

            $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
            $i++;
            $i = $i % 7;
        }

        for ($j = 0; $j < 7; $j++) {
            if (!(isset($data[$j]))) {
                $data[$j] = array();
            }
        }


        $this->render('celyRozvrh', array('thisWeek' => $data, 'start' => $start_date, 'tt' => $timet));
    }

    /* ____________________________________________________________________________ */

    public function actionShowHour($date, $time) {
        @session_start();
        $this->layout = '//layouts/trainer';
        $time = str_replace('-', ':', $time);

        $_SESSION['date'] = $date;
        $_SESSION['time'] = $time;

        if (isset($_POST['odoslat'])) {
            if (isset($_POST['presence'])) {
                foreach (array_keys($_POST['presence']) as $single) {
                    $solo = Hours::model()->findByPk($single);
                    if ($solo->tryout == 1) {
                        $kid = Kids::model()->findbyPk($solo->ID_kids);
                        $kid->tryout = 1;
                        $kid->save();
                    }
                    $solo->present = $_POST['presence'][$single];
                    $solo->save();
                }
            }
        }

        $wd = date('N', strtotime($date));

        $tts = Timetable::model()->findAllByAttributes(array(
            'week_day' => $wd,
            'time_start' => $time,
        ));

        foreach ($tts as $tt) {
            $enl[] = Enlist::model()->findAllByAttributes(array(
                'ID_timet' => $tt->ID,
            ));
        }

        $kidl = array();
        $tenl = array();

        foreach ($enl as $one) {
            foreach ($one as $sin) {
                $tenl[] = $sin;
                $kidl[] = Kids::model()->findByPk($sin->ID_kid);
            }
        }

        $data = Hours::model()->findAllByAttributes(array(
            'date' => $date,
            'time_start' => $time,
                ), array(
            'order' => 'ID_timet'
        ));

        $trainers = array();
        foreach ($data as $dat) {
            if (!(in_array($dat->trainer, $trainers))) {
                $trainers[] = $dat->trainer;
            }
        }
        $tr_arr = array();
        foreach ($trainers as $single) {
            $tr_arr[$single] = Users::model()->findByPk($single);
        }
        $new_trim_choice = Settings::model()->findByAttributes(array('type'=>'new_trim_trainer_choice'));

        //print_r (array_keys($_POST['presence']));
        $this->render('showHour', array('data' => $data, 'trainers' => $tr_arr, 'tts' => $kidl, 'tenl' => $tenl, 'new_trim'=>$new_trim_choice));
    }

    public function actionShowHourTrainer($date, $time, $trainer, $lesson) {
        $this->layout = '//layouts/trainer';
        $time = str_replace('-', ':', $time);

        if (isset($_POST['odoslat'])) {
            if (isset($_POST['presence'])) {
                foreach (array_keys($_POST['presence']) as $single) {
                    $solo = Hours::model()->findByPk($single);
                    if ($solo->tryout == 1) {
                        $kid = Kids::model()->findbyPk($solo->ID_kids);
                        $kid->tryout = 1;
                        $kid->save();
                    }
                    $solo->present = $_POST['presence'][$single];
                    $solo->save();
                }
            }
        }

        $wd = date('N', strtotime($date));

        $tts = Timetable::model()->findAllByAttributes(array(
            'week_day' => $wd,
            'time_start' => $time,
            'trainer' => $trainer,
            'lesson' => $lesson
        ));

        foreach ($tts as $tt) {
            $enl[] = Enlist::model()->findAllByAttributes(array(
                'ID_timet' => $tt->ID,
            ));
        }

        $kidl = array();
        $tenl = array();

        foreach ($enl as $one) {
            foreach ($one as $sin) {
                $tenl[] = $sin;
                $kidl[] = Kids::model()->findByPk($sin->ID_kid);
            }
        }

        $data = Hours::model()->findAllByAttributes(array(
            'date' => $date,
            'time_start' => $time,
            'trainer' => $trainer,
            'lesson' => $lesson
                ), array(
            'order' => 'ID_timet'
        ));

        $trainers = array();
        foreach ($data as $dat) {
            if (!(in_array($dat->trainer, $trainers))) {
                $trainers[] = $dat->trainer;
            }
        }
        $tr_arr = array();
        foreach ($trainers as $single) {
            $tr_arr[$single] = Users::model()->findByPk($single);
        }

        //print_r (array_keys($_POST['presence']));
        $this->render('showHour', array('data' => $data, 'trainers' => $tr_arr, 'tts' => $kidl, 'tenl' => $tenl));
    }

    /* ____________________________________________________________________________ */

    public function actionZobrazPotvrdenie($id, $date) {

        $hod = Hours::model()->findByPk($id);
        $dieta = Kids::model()->with('parrent')->findbyPk($hod->ID_kids);
        date_default_timezone_set('CET');


        //////////////vypocet paymentu

        $cursemid = '';
        $cursem = Semesters::model()->findAll();
        foreach ($cursem as $sm) {

            $semdate = $sm->date_start;
            //date('Y-m-d', strtotime("+8 day", strtotime($date)));
            $end_date = $sm->date_end;


            while (strtotime($semdate) < strtotime($end_date)) {

                if ($semdate == date('Y-m-d')) {
                    $cursemid = $sm->ID;
                }
                $semdate = date('Y-m-d', strtotime("+1 day", strtotime($semdate)));
            }
        }

        $sdate = $date;
        $cursem = Semesters::model()->findByPk($cursemid);
        $edate = $cursem->date_end;

        while (strtotime($sdate) <= strtotime($edate)) {

            $sdate = date("Y-m-d", strtotime("+1 day", strtotime($sdate)));
        }

        $holiday = Holiday::model()->findAll();
        $hol_array = array();

        foreach ($holiday as $hd) {
            $date_ = $hd->date_start;
            if (isset($hd->date_end)) {
                $end_date_ = $hd->date_end;
            } else {
                $end_date_ = $hd->date_start;
            }
            while (strtotime($date_) <= strtotime($end_date_)) {
                $hol_array[] = $date_;
                $date_ = date("Y-m-d", strtotime("+1 day", strtotime($date_)));
            }
        }

        $n = 0;
        $enlkid = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
            'ID_kid' => $dieta->ID,
        ));
        // zistit aky to je den
        foreach ($enlkid as $key) {
            $enlday[] = (int) $key->iDTimet->week_day;
        }

        $finalcount = 0;
        //$i = ((int)date('w')-1)%7;
        //pre semester = od zaciatku semestra, po koniec
        $sdate = date('Y-m-d', strtotime("+1 day", strtotime($date)));          //+7
        $od = $sdate;

        //date('Y-m-d', strtotime("+8 day", strtotime($date)));
        $edate = $cursem->date_end;
        $do = $edate;
        //print_r($sdate);

        $comp = array();

        while (strtotime($sdate) <= strtotime($edate)) {
            if (in_array(date('N', strtotime($sdate)), $enlday)) {
                if (!(in_array($sdate, $hol_array))) {
                    $iter = array_count_values($enlday);
                    $comp[] = $sdate;
                    $finalcount += $iter[date('N', strtotime($date))];
                }
            }
            $sdate = date('Y-m-d', strtotime("+1 day", strtotime($sdate)));
        }



        //////////////vypocet paymentu

        if (isset($_POST['unmake']) && ($_POST['unmake'] == 'delete')) {
            foreach ($enlkid as $key) {
                $key->delete();
            }
            $dieta->tryout = 1;
            $dieta->active = 0;
            if ($dieta->save()){
                Yii::app()->user->setFlash('success', "Zmeny úspešne uložené.");
            } else {
                Yii::app()->user->setFlash('error', "Uloženie zlyhalo.");
            }
            $this->redirect(array('trainer/celyRozvrh','for'=>date('Y-m-d')));
        }

////////////////////////////////////////////////////////////////////////////////
        if (isset($_POST['calc']) && isset($_POST['account']) /* && isset($_POST['varsym']) */) {


            //dietatu dat absolvovanu, hodinu.
            $dieta->tryout = 1;
            $dieta->save();

            //platba
            $platba = new Payments;
            $platba->ID_kid = $dieta->ID;
            $platba->date = date('Y-m-d');
            $platba->trimester = $cursem->ID;
            $platba->n_of_hours = $_POST['calc']['nhours'];
            $platba->prize_per_h = $_POST['calc']['phour'];
            $platba->discount = $_POST['calc']['disc'];
            //$platba->VS = $_POST['varsym'];
            $platba->VS = '00000000';
            $platba->payed = 0;
            if ($platba->validate()) {
                $platba->save();
                $platba->VS = '100' . $platba->ID; //ruzinov ma 100+ID platby -> treba presunut do nastaveni
                $platba->save();
            }

            $iDK = $dieta->ID;
            $begd = date('Y-m-d', strtotime("+1 day", strtotime($date)));       //+7
            $endd = $cursem->date_end;

            Yii::app()->helper->generateHours($iDK, $begd, $endd);


            $zlava_text= '';
            if ($_POST['calc']['disc'] != '0') {
                $zlava_text = 'Zľava:                ' . $_POST['calc']['disc'] . ' % <br />';
            }


            //odoslanie mailu rodicovi:
            $umodel = Users::model()->findByPk($dieta->parrent_ID);
            $mailbody = '
    <html>
    <head></head>
    <body>


  Ďakujeme za Váš záujem o využívanie našich služieb.<br />
  <br />
  Dovoľujeme si Vám zaslať detailné informácie potrebné k realizácii platby za Vaše dieťa:<br />
  <br />
  ' . $dieta->name . ' ' . $dieta->surname . '<br />
  Trimester:  ' . $cursem->label . '<br />
  <br />
  Dátumy vygenerovaných hodín:<br />
  ' . implode(', ', $comp) . '
  <br /><br />
  Počet hodín:          ' . $_POST['calc']['nhours'] . ' na trimester <br />
  Suma za hod.:         ' . $_POST['calc']['phour'] . ' EUR <br />
  Celková suma:         ' . $_POST['calc']['brutt'] . ' EUR <br />
  '.$zlava_text.'
  Suma na zaplatenie:   ' . $_POST['calc']['nett'] . ' EUR <br />
  <br />
  Uvedenú sumu prosím uhraďte prevodom na náš bankový účet do siedmich dní od dátumu doručenia tohto emailu.<br />
  <br />
  Číslo účtu BigHugGym:	' . $_POST['account'] . ' <br />
  Variabilný symbol:    ' . $platba->VS . ' <br />
  <br />
  Do komentára k transakcii dopíšte aj meno a priezvisko Vášho dietaťa pre jednoduchšiu identifikáciu. <br />
  <br />
  Ďakujeme.<br />
  Vážime si, že využívate naše služby.<br />
  <br />
  S pozdravom <br />
  Váš tím BigHugGym <br />


    </body>
    </html>
    ';

            $headers = 'MIME-Version: 1.0' . "\r\n";
            $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
            $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
            $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n";

            $rcpt = $umodel->email;
            $subj = 'BigHugGym – výzva na zaplatenie';

            if (mail($rcpt, $subj, $mailbody, $headers)) {
                mail('kontrola.ruzinov@bighuggym.sk', 'ZALOHA: ' . $subj, $mailbody, $headers);
                Yii::app()->user->setFlash('success', "Systém BHG zaevidoval pokračovanie dieťaťa v tréningoch. Boli vygenerované hodiny a platba. Informácie boli odoslané rodičovi dieťaťa a tiež na kontrolný mail do BHG.");
                $this->redirect(array('trainer/index'));
            }
        }//koniec isset post
        //poslat mail rodicovi
////////////////////////////////////////////////////////////////////////////////

        $enlists = Enlist::model()->findAllByAttributes(array(
            'ID_kid' => $hod->ID_kids,
        ));

        if (($dieta->lesson == 1) || ($dieta->lesson == 2) || ($dieta->lesson == 9)) {
            $ucet = 'SK7802000000003204308959';
            //pre S.R.O. - SK7802000000003204308959
            //pre OZ - SK3802000000003528888654
        } else {
            $ucet = 'SK3802000000003528888654';
        }

        //vygenerovat a vypocitat payment
        $this->render('zobrazPotvrdenie', array('dieta' => $dieta, 'zapisane' => $enlists, 'trim' => $cursem, 'fcount' => $finalcount, 'od' => $od, 'do' => $do, 'ucet' => $ucet, 'dbg' => $comp));
    }

    public function actionZobrazKlientov() {
        $this->render('zobrazKlientov');
    }

    public function actionDieta($id) {
        $kid = Kids::model()->with('parrent')->findByPk($id);
        $hours = Hours::model()->findAllByAttributes(array('ID_kids' => $id));
        $enlist = Enlist::model()->with('iDTimet')->findAllByAttributes(array('ID_kid' => $id));
        $tryhour = Hours::model()->findByAttributes(array('ID_kids' => $id, 'tryout' => 1));
        $platby = Payments::model()->findAllByAttributes(array('ID_kid' => $id));

        $this->render('dieta', array('kid' => $kid, 'hours' => $hours, 'enlist' => $enlist, 'tryhour' => $tryhour, 'payments' => $platby));
    }

    public function actionUser($id) {
        $model = Users::model()->findByPk($id);

        if (isset($_POST['Users'])) {
            if ($_POST['Users']['password'] != $model->password) {
                $model->attributes = $_POST['Users'];
                $model->password = hash('sha256', $model->password);
            } else {
                $model->attributes = $_POST['Users'];
            }
            if ($model->validate()) {
                $model->save();
                $this->redirect(array('user', 'id' => $model->ID));
            }
        }

        $this->render('user', array('model' => $model));
    }

    public function actionZobrazDeti() {
        $model = Kids::model()->findAll(array('order' => 'surname ASC'));
        $this->render('zobrazDeti', array('deti' => $model));
    }

    public function actionZobrazRodicov() {
        $model = Users::model()->findAllByAttributes(array(
            'rights_ID' => '2'
                ), array('order' => 'surname ASC'));

        $this->render('zobrazUserov', array('data' => $model, 'typ' => 'Rodič'));
    }

    public function actionPomoc() {
        $this->render('pomoc');
    }

    public function actionMojeUdaje() {
        $curU = Users::model()->findByPk(Yii::app()->user->getId());

        if (isset($_POST['Users'])) {
            if ($_POST['Users']['password'] == '' || (!(isset($_POST['Users']['password'])))) {
                $_POST['Users']['password'] = $curU->password;
            } else {
                if ($_POST['Users']['password'] == $_POST['Users']['password2']) {
                    $_POST['Users']['password'] = hash('sha256', $_POST['Users']['password']);
                } else {
                    Yii::app()->user->setFlash('error', "Heslo nebolo uložené! Prosím zadajte 2 krát rovnaké heslo.");
                }
            }
            $curU->attributes = $_POST['Users'];
            if ($curU->save()) {
                Yii::app()->user->setFlash('success', "Dáta uložené!");
            }
        }

        $curU->password = "";
        $this->render('user', array('model' => $curU));
    }

    public function actionZobrazText($id) {
        $model = Kids::model()->with('parrent')->findByPk($id);

        $sro = '
<pre>
Súhlas dotknútej osoby

Prevádzkovateľ
BigHugGym, s.r.o., Drieňova 1/C, 82101 Bratislava, IČO 45375879

Dotknutá osoba
Meno:     ' . $model->parrent->surname . ' ' . $model->parrent->name . '
Telefón:  ' . $model->parrent->phone_num . '
Email:    ' . $model->parrent->email . '

Dieťa
Meno:             ' . $model->surname . ' ' . $model->name . '
Dátum narodenia:  ' . $model->birthday . '

Dotknutá osoba poskytuje Prevádzkovateľovi podľa § 10 ods. 3 písm. b) zákona č. 122/2013
Z. z. o ochrane osobných údajov a o zmene a doplnení niektorých zákonov v znení neskorších
predpisov (ďalej len „Zákon“) svoje osobné údaje v rozsahu meno, priezvisko, adresa, telefón,
email zákonného zástupcu a meno, priezvisko, dátum narodenia dieťaťa, a to na účely
poskytnutia objednanej služby – vzdelávací gymnastický program. Bez poskytnutia osobných
údajov nemôže byť služba poskytnutá.

&#9744; Súhlasím so zhotovovaním a zverejňovaním obrazových, zvukových a zvukovo-obrazových
záznamov z lekcií/pretekov/akcií/podujatí, a to na web stránke Prevádzkovateľa, fun page na
sociálnej sieti alebo akýchkoľvek iných miestach a dokumentoch na účely propagácie
Prevádzkovateľa; Fotografie a videá môžu byť zhotovované Prevádzkovateľom alebo jeho
zmluvným partnerom.

&#9744; Súhlasím so zasielaním informácií o nových kurzoch a aktivitách Prevádzkovateľa a OZ
BigHugGym na moju emailovú adresu.

&#9744; Súhlasím so spracúvaním osobných údajov v rozsahu ako boli poskytnuté na prihláške na
účely vernostného a zľavového programu.
Svoj súhlas udeľujem na dobu 3 rokov. Udelený súhlas je možné kedykoľvek odvolať zaslaním
žiadosti na emailovú adresu prevádzkovateľa alebo písomnej žiadosti na adresu sídla
prevádzkovateľa.

Ako dotknutá osoba vyhlasujem, že som si vedomá svojich práv v zmysle § 28 Zákona a že
mi boli poskytnuté informácie v súlade s § 15 Zákona.

Zároveň vyhlasujem, že poskytnuté osobné údaje sú pravdivé, boli poskytnuté slobodne a za
nepravdivosť osobných údajov zodpovedám v zmysle § 68 ods. 7 písm. b) Zákona. Zároveň
sa zaväzujem každú zmenu poskytnutých osobných údajov nahlásiť Prevádzkovateľovi do 15
dní odo dňa uskutočnenia zmeny.


Dátum:  ' . date('d.m.Y') . '                                     Podpis:

</pre>
';

        $oz = '
<pre>
Súhlas dotknútej osoby

Prevádzkovateľ
OZ Big Hug Gym, Drieňova 1/C, 82101 Bratislava, IČO 42446481

Dotknutá osoba
Meno:     ' . $model->parrent->surname . ' ' . $model->parrent->name . '
Telefón:  ' . $model->parrent->phone_num . '
Email:    ' . $model->parrent->email . '

Dieťa
Meno:             ' . $model->surname . ' ' . $model->name . '
Dátum narodenia:  ' . $model->birthday . '

Týmto ako dotknutá osoba udeľujem podľa § 11 zákona č. 122/2013 Z. z. o ochrane osobných
údajov a o zmene a doplnení niektorých zákonov v znení neskorších predpisov (ďalej len
„Zákon“) súhlas so spracúvaním osobných údajov o mojej osobe v rozsahu meno, priezvisko,
adresa, telefón, email zákonného zástupcu a meno, priezvisko, dátum narodenia dieťaťa, a to
na účely činnosti Prevádzkovateľa a plnenia jeho úloh podľa stanov a uplatňovania práv
a povinností vyplývajúcich z členstva v OZ Big Hug Gym a klube. Svoj súhlas udeľujem na
dobu trvania členstva. Udelený súhlas je možné kedykoľvek odvolať zaslaním žiadosti na
emailovú adresu prevádzkovateľa alebo písomnej žiadosti na adresu sídla prevádzkovateľa.

&#9744; Súhlasím so zhotovovaním a zverejňovaním obrazových, zvukových a zvukovo-obrazových
záznamov z lekcií/pretekov/akcií/podujatí, a to na web stránke Prevádzkovateľa, fun page na
sociálnej sieti alebo akýchkoľvek iných miestach a dokumentoch na účely propagácie
Prevádzkovateľa a gymnastiky vôbec v súlade s poslaním Prevádzkovateľa a klubu; Fotografie
a videá môžu byť zhotovované Prevádzkovateľom alebo jeho zmluvným partnerom.

&#9744; Súhlasím so zasielaním informácií o nových kurzoch a aktivitách Prevádzkovateľa
a BigHugGym, s.r.o. na moju emailovú adresu.

&#9744; Súhlasím so spracúvaním osobných údajov v rozsahu ako boli poskytnuté na prihláške na
účely vernostného a zľavového programu.

Ako dotknutá osoba vyhlasujem, že som si vedomá svojich práv v zmysle § 28 Zákona a že
mi boli poskytnuté informácie v súlade s § 15 Zákona.

Zároveň vyhlasujem, že poskytnuté osobné údaje sú pravdivé, boli poskytnuté slobodne a za
nepravdivosť osobných údajov zodpovedám v zmysle § 68 ods. 7 písm. b) Zákona. Zároveň
sa zaväzujem každú zmenu poskytnutých osobných údajov nahlásiť Prevádzkovateľovi do 15
dní odo dňa uskutočnenia zmeny.


Dátum:  ' . date('d.m.Y') . '                                     Podpis:

</pre>
';
        if ((($dieta->lesson == 1) || ($dieta->lesson == 2) || ($dieta->lesson == 9))) {
            $text = $sro;
        } else {
            $text = $oz;
        }

        $this->render('zobrazText', array('model' => $model, 'text' => $text));
    }

    public function actionUserProfile($id){
        //User with payments, Kid with test hours, + enlist
        $parent = Users::model()->findByPk($id);
        $kids = Kids::model()->with(array('enlists', 'payments'))->findAllByAttributes(array('parrent_ID'=>$id));
        foreach ($kids as $value) {
            $tryout[$value->ID] = Hours::model()->findAllByAttributes(array('ID_kids'=>$value->ID,'tryout'=>1));
        }
        $this->render('userProfile', array('parent'=>$parent, 'kids'=>$kids, 'try'=>$tryout));

    }

//****************************************************************************//
    public function actionTNovyTrim($id) {
        //$this->layout = '//layouts/manazment';
        //$curU = Users::model()->findByPk(Yii::app()->user->getId());
        $kid = Kids::model()->findByAttributes(array(
            'ID' => $id,
                //    'parrent_ID' => $curU->ID,
        ));


        $val = Metadata::model()->findByAttributes(array(
            'refTO' => 'dieta',
            'refID' => $id,
            'dataNAME' => 'hlasovanie',
        ));

        if ($val != null) {
            $val = $val->data;
        } else {
            $val = 0;
        }

        $this->render('novyTrim', array('id' => $id, 'dieta' => $kid, 'already' => $val));
    }

    public function actionTPokracovanie($id) {

        $dieta = Kids::model()->findBypk($id);
        /*
          $curU = Users::model()->findByPk(Yii::app()->user->getId());
          $dieta = Kids::model()->findByAttributes(array(
          'ID' => $id,
          'parrent_ID' => $curU->ID,
          ));
         */
        $enlist = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
            'ID_kid' => $id
        ));
        if (isset($_POST['skopiruj'])) {
            foreach ($enlist as $single) {
                $nenl = new Newenlist();
                $nenl->setAttributes($single->getAttributes(), false);
                $nenl->save();
            }

            $zapis = new Metadata('hlasovanie');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'hlasovanie';
            $zapis->data = '1'; //bolo zahlasovane;
            $zapis->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            $this->redirect(array('trainer/showHour', 'date' => $_SESSION['date'], 'time' =>$_SESSION['time'])); // presmerovanie na deti
        }
        $this->render('pokracovanie', array('id' => $id, 'enl' => $enlist, 'dieta' => $dieta));
    }

    public function actionTNovyQuery($id) {
        //kid_id
        //zapis do query podla rozvrhu.

        $dieta = Kids::model()->findByAttributes(array(
            'ID' => $id,
                //'parrent_ID' => $curU->ID,
        ));

        if (isset($_POST['zmenit'])) {
            $zapis = new Metadata('zmenit');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'pokracovanie';
            $zapis->data = '1'; //nechce pokracovat;
            $zapis->save();
            //print_r($zapis->validate());

            $zapis0 = new Metadata('hlasovanie');
            $zapis0->refID = $id;
            $zapis0->refTO = 'dieta';
            $zapis0->dataNAME = 'hlasovanie';
            $zapis0->data = '1'; //bolo zahlasovane;
            $zapis0->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            //print_r($zapis0->validate());
            $this->redirect(array('trainer/showHour', 'date' => $_SESSION['date'], 'time' =>$_SESSION['time']));
        }
        $this->render('novyQuery', array('id' => $id, 'dieta' => $dieta));
    }

    public function actionTNepokracovanie($id) {
        //nezela si pokracovat? co tu? deaktivacia dietata, rodica?
        /**
         * This is the model class for table "metadata".
         *
         * The followings are the available columns in table 'metadata':
         * @property integer $ID
         * @property string $refTO
         * @property integer $refID
         * @property integer $dataNAME
         * @property string $data
         */
        $dieta = Kids::model()->findByAttributes(array(
            'ID' => $id,
        ));
        if (isset($_POST['skoncit'])) {
            $zapis = new Metadata('skoncit');
            $zapis->refID = $id;
            $zapis->refTO = 'dieta';
            $zapis->dataNAME = 'pokracovanie';
            $zapis->data = '0'; //nechce pokracovat;
            $zapis->save();

            $zapis0 = new Metadata('hlasovanie');
            $zapis0->refID = $id;
            $zapis0->refTO = 'dieta';
            $zapis0->dataNAME = 'hlasovanie';
            $zapis0->data = '1'; //bolo zahlasovane;
            $zapis0->save();

            $thiskid = Kids::model()->findByPk($id);

            $zapis1 = new Metadata('hlasovanie_r');
            $zapis1->refID = $thiskid->parrent_ID;
            $zapis1->refTO = 'rodic';
            $zapis1->dataNAME = 'hlasoval';
            $zapis1->data = '1'; //bolo zahlasovane;
            $zapis1->save();

            $this->redirect(array('trainer/showHour', 'date' => $_SESSION['date'], 'time' =>$_SESSION['time']));
        }
        //@print_r($_POST);
        $this->render('nepokracovanie', array('id' => $id, 'dieta' => $dieta));
    }

}
