<?php

class EnlistController extends Controller
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
			'postOnly + delete', // we only allow deletion via POST request
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array(''),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array(''),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('index', 'view', 'admin','delete','create','update', 'admincreate'),
				'users'=>array('admin.ruz@bighuggym.com', 'PtacinJan', 'jan.ptacin@gmail.com'),
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}
	/**
	 * Displays a particular model.
	 * @param integer $id the ID of the model to be displayed
	 */
	public function actionView($id)
	{
		$this->render('view',array(
			'model'=>$this->loadModel($id),
		));
	}

	/**
	 * Creates a new model.
	 * If creation is successful, the browser will be redirected to the 'view' page.
	 */
	public function actionCreate()
	{
		$model = new Enlist;

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Enlist']))
		{
			$model->attributes=$_POST['Enlist'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->ID));
		}

		$this->render('create',array(
			'model'=>$model,
		));
	}


  // timetable ID as param
	public function actionAdmincreate($tid) {
        $model = new Enlist;
        $enlisted = Enlist::model()->findAllByAttributes(array(
            'ID_timet' => $tid,
        ));

        $klinks = array();
        $allk = array();
        foreach ($enlisted as $value) {
            $tkid = Kids::model()->with(array('payments' => array('order' => 'date desc', 'limit' => 1)))->findByPK($value->ID_kid);
//            array_push($klinks, CHtml::link( $tkid->surname.' '.$tkid->name.'<br />', array('kids/view','id'=>$value->ID_kid), array('target'=>'_blank')));
            $allk[] = $tkid;
            //$klinks = CHtml::link( $tkid->surname.' '.$tkid->name.'<br />', array('kids/view','id'=>$value->ID_kid));
        }

        // Uncomment the following line if AJAX validation is needed
        // $this->performAjaxValidation($model);

        if (isset($_POST['Enlist'])) {
            $model->attributes = $_POST['Enlist'];
            if ($model->save())
                $this->redirect(array('admincreate', 'tid' => $tid));
        }

        $this->render('admincreate', array(
            'model' => $model,
//                        'links'=>$klinks,
            'ttid' => $tid,
            'tkid' => $allk,
        ));
    }

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		$model=$this->loadModel($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Enlist']))
		{
			$model->attributes=$_POST['Enlist'];
			if($model->save())
				$this->redirect(array('view','id'=>$model->ID));
		}

		$this->render('update',array(
			'model'=>$model,
		));
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		$this->loadModel($id)->delete();

		// if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
		if(!isset($_GET['ajax']))
			$this->redirect(isset($_POST['returnUrl']) ? $_POST['returnUrl'] : array('admin'));
	}

	/**
	 * Lists all models.
	 */
	public function actionIndex()
	{
		$dataProvider=new CActiveDataProvider('Enlist');
		$this->render('index',array(
			'dataProvider'=>$dataProvider,
		));
	}

	/**
	 * Manages all models.
	 */
	public function actionAdmin()
	{
		$model=new Enlist('search');
		$model->unsetAttributes();  // clear any default values
		if(isset($_GET['Enlist']))
			$model->attributes=$_GET['Enlist'];

		$this->render('admin',array(
			'model'=>$model,
		));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer $id the ID of the model to be loaded
	 * @return Enlist the loaded model
	 * @throws CHttpException
	 */
	public function loadModel($id)
	{
		$model=Enlist::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404,'The requested page does not exist.');
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param Enlist $model the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='enlist-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}
}
