<?php

class ManagerController extends Controller
{

  public function init(){
        Yii::app()->errorHandler->errorAction='manager/error';
  }
	/**
	 * Declares class-based actions.
	 */
	public $layout = '//layouts/manager-layout';
  
  public function actions()
	{
		return array(
			// captcha action renders the CAPTCHA image displayed on the contact page
			'captcha'=>array(
				'class'=>'CCaptchaAction',
				'backColor'=>0xFFFFFF,
			),
			// page action renders "static" pages stored under 'protected/views/site/pages'
			// They can be accessed via: index.php?r=site/page&view=FileName
			'page'=>array(
				'class'=>'CViewAction',
			),
		);
	}

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'accessControl', // perform access control for CRUD operations
		);
	}

	/**
	 * Specifies the access control rules.
	 * This method is used by the 'accessControl' filter.
	 * @return array access control rules
	 */
	public function accessRules()
	{
		return array(
			array('allow',  // allow all users to perform 'index' and 'view' actions
				'actions'=>array(''),
				'users'=>array('*'),
			),
			array('allow', // allow authenticated user to perform 'create' and 'update' actions
				'actions'=>array(''),
				'users'=>array('@'),
			),
			array('allow', // allow admin user to perform 'admin' and 'delete' actions
				'actions'=>array('index', 'error', 'contact', 'zobrazDeti', 'zobrazRodicov', 'zobrazManagerov', 'zobrazTrenerov', 'zobrazKlientov', 'dieta', 'enlist', 'user', 'showWeekHours', 'showTimetable', 'generatePayment', 'confirmPayment', 'enlistGenerate', 'showTimetable', 'showHour'),
				//'users'=>array('admin'),
        'expression' => array('ManagerController','allowOnlyOwner')
			),
			array('deny',  // deny all users
				'users'=>array('*'),
			),
		);
	}  


  /**
   * Allow only the owner to do the action
   * @return boolean whether or not the user is the owner
   */
  public function allowOnlyOwner(){
    if(isset(Yii::app()->user->userRightsId)){    
      if(Yii::app()->user->userRightsId == '1'){
          return true;
      }
    }
    else {
      return false;
    }
  }

  public function actionZobrazDeti()
  {
    $model = Kids::model()->findAll();
    $this->render('zobrazDeti', array('deti'=>$model));
  }
  
  public function actionZobrazRodicov()
  {
    $model = Users::model()->findAllByAttributes(array(
      'rights_ID' => '2'
    ));
    
    $this->render('zobrazUserov', array('data'=>$model, 'typ'=>'Rodič'));
  }
  
  public function actionZobrazManagerov()
  {
    $model = Users::model()->findAllByAttributes(array(
      'rights_ID' => '1'
    ));
    $this->render('zobrazUserov', array('data'=>$model, 'typ'=>'Manager'));
  }
  
  public function actionZobrazTrenerov()
  {
    $model = Users::model()->findAllByAttributes(array(
      'rights_ID'=>'3',
    ));
    $this->render('zobrazUserov', array('data'=>$model, 'typ'=>'Tréner'));
  }
  
  public function actionZobrazKlientov(){
    $this->render('zobrazKlientov');
  }	
  
  public function actionDieta($id){
    $model = Kids::model()->findByPk($id);
    $enlists = Enlist::model()->findAllByAttributes(array(
    'ID_kid'=>$model->ID,
    ));
    
    if(isset($_POST['Kids'])){
      $model->attributes = $_POST['Kids'];
      if($model->validate()){
        $model->save();  
      }
    }
    
    $this->render('dieta', array('data'=>$model, 'enl'=>$enlists)); 
      
  }

  public function actionEnlist($id){
    $model = Enlist::model()->findByPk($id);
    
    if(isset($_POST['Enlist'])){
      $model->attributes = $_POST['Enlist'];
      if($model->validate()){
        $model->save();
      }
    }
    if(isset($_POST['delete'])){
      $model->delete();
      $this->redirect(array('zobrazKlientov'));
    }
    
    $this->render('enlist', array('data'=>$model));
  }

  public function actionUser($id){
    $model = Users::model()->findByPk($id);

    if(isset($_POST['Users'])){
      $model->attributes = $_POST['Users'];
      $model->password = hash('sha256', $model->password);
      if ($model->validate()){
        $model->save();
        $this->redirect(array('user','id'=>$model->ID));
      }  
    }    
    
    $this->render('user', array('data'=>$model)); 
  }
  
  /**
	 * This is the default 'index' action that is invoked
	 * when an action is not explicitly requested by users.
	 */
	public function actionIndex()
	{
		//$this->layout = '//layouts/manazer';
    // renders the view file 'protected/views/site/index.php'
		// using the default layout 'protected/views/layouts/main.php'
		$this->render('index');
	}

   
  
	/**
	 * This is the action to handle external exceptions.
	 */
	public function actionError()
	{
		if($error=Yii::app()->errorHandler->error)
		{
			if(Yii::app()->request->isAjaxRequest)
				echo $error['message'];
			else
				$this->render('error', $error);
		}
	}
  
  public function actionShowWeekHours(){
    date_default_timezone_set('CET');
    
    $model = array();
    $date = date('Y-m-d');
    //find prev monday
    while (date('D', strtotime($date))!='Mon'){
      $date = date('Y-m-d', strtotime("-1 day", strtotime($date))); 
    }
    
    $start_date = $date;
    $end_date = date('Y-m-d', strtotime("+14 day", strtotime($date)));
    
    while (strtotime($date) <= strtotime($end_date)) {
      $model[] = Hours::model()->findAllByAttributes(array('date'=>$date));
      $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));
      foreach ($model[end(array_keys($model))] as $current) {
      	$model[end(array_keys($model))]['hours'][] = $current->time_start;
      }     
    }
      
    $this->render('showWeekHours', array('thisWeek'=>$model, 'startDay'=>$start_date));
  }

  public function actionShowTimetable()
  {
  $new_enlist = new Enlist('rozvrh');
  $vsetky_roz = Timetable::model()->findAll();
  $vsetky_prih = Enlist::model()->findAll();
  
  
    $this->render('showTimetable',array('rozvrhy'=>$vsetky_roz, 'prihlasenia'=>$vsetky_prih));
  }

  public function actionGeneratePayment()
  {
    $model = new Payments();
    
    $data = Users::model()->with('kids')->findAllByAttributes(array(
      'rights_ID'=>'2',
    ),array(
      'order'=>'t.surname ASC'
    ));
    //$kids = Kids::model()->with('payments')->findAll();
    
    //for which child/parent
    $semesters = Semesters::model()->findAll();
    //for semester
    //var symb?
    
    if(isset($_POST['kidID']) && isset($_POST['semID'])){
    //generuj paymanet
      $thiskid = Kids::model()->findByPk($_POST['kidID']);     
      $thissem = Semesters::model()->findByPk($_POST['semID']);
      
      $par = Users::model()->findByPk($thiskid->parrent_ID);
     
      
      $model->ID_kid = $_POST['kidID'];
      $model->date = date('Y-m-d');
      $model->trimester = $_POST['semID'];
      

      $holiday = Holiday::model()->findAll();
      //obsahuje datumy vsetkych prazdnin
      $hol_array = array();
      
      foreach ($holiday as $hd) {
        $date_ = $hd->date_start;
        $end_date_ = $hd->date_end;

      	while (strtotime($date_) <= strtotime($end_date_)) {
          $hol_array[] = $date_;          
          $date_ = date ("Y-m-d", strtotime("+1 day", strtotime($date_)));
        }
      }

      // treba zobrat vsetky enlisty
      $enlkid = Enlist::model()->with('iDTimet')->findAllByAttributes(array(
        'ID_kid'=>$thiskid->ID,
      ));
      // zistit aky to je den
      foreach ($enlkid as $key) {
        $enlday[] = (int) $key->iDTimet->week_day;	
      }
      
      // prechadzat nasledujucimi tyzdnami az po koniec semestra
      // ak tam nie ju sprazdniny, pripocitat.
      
      
           
      $c = 0;
      //$i = ((int)date('w')-1)%7;
      //pre semester = od zaciatku semestra, po koniec
      $date = $thissem->date_start; 
      //date('Y-m-d', strtotime("+8 day", strtotime($date)));
      $end_date = $thissem->date_end;
      
      
      while (strtotime($date) < strtotime($end_date)) {
      
        if(in_array(date('N', strtotime($date)), $enlday)){
          if(!(in_array($date, $hol_array))){
            $iter = array_count_values($enlday);
            $c += $iter[date('N', strtotime($date))];
          } 
        }
      
      
        $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));  
      }      
      
      
      
      $model->n_of_hours = $c; //vypocitat.
      
      
      if($thiskid->frequency == 2)
      {
        $model->prize_per_h = Yii::app()->params['pricePerHourDiscount'];
      } else {
        $model->prize_per_h = Yii::app()->params['pricePerHour'];
      }
      
      $model->discount = 0; //v zavislosti od mnzostva deti
      
      $model->payed = 0;
      $model->VS = '0000000000';
      //10 znakov netusim ako generovat;

      if ($model->validate()) {
        $model->save();
      }
    //print_r($model);
    }
    
    //cur semester
    $cursemid = '';
    $cursem = Semesters::model()->findAll();
    foreach ($cursem as $sm){
      
      $date = $sm->date_start; 
      //date('Y-m-d', strtotime("+8 day", strtotime($date)));
      $end_date = $sm->date_end;
      
      
      while (strtotime($date) < strtotime($end_date)) {
      
        if($date == date('Y-m-d')) {
          $cursemid = $sm->ID;    
        }
        $date = date('Y-m-d', strtotime("+1 day", strtotime($date)));  
      }    
    }
    
    $pay = Payments::model()->with('kid', 'trimester_')->findAllByAttributes(array(
      'trimester'=>$cursemid,      
      ), array('order' => 'date DESC')
    );
    
    //print_r($this);
    $this->render('generatePayment',array(
			'model'=>$model, 
      'data'=> $data, 
      'semesters' => $semesters,
      'payments' => $pay,
      //'kids' => $kids,
    ));
  }

  public function actionConfirmPayment($id){
    $model = Payments::model()->findByPk($id);
    
    $model->payed = 1;
    
    $model->save();
    
    $kid = Kids::model()->with('parrent')->findByPk($model->ID_kid);    
    $trimester = Semesters::model()->findByPk($model->trimester);
    
    //poslat mail
    $headers  = 'MIME-Version: 1.0' . "\r\n";
    $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";  
    $headers .= 'From: ' . Yii::app()->params['adminEmail'] . "\r\n";
    $headers .= 'Reply-To: ' . Yii::app()->params['adminEmail'] . "\r\n"; 

    $message = '
    <html>
    <head>
       <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
       <title>Potvrdenie platby</title>
    </head>
    <body>
      Vážený pán/pani '.$kid->parrent->surname.',<br />           
      Platbu za Vaše dieťa '.$kid->name.' '.$kid->surname.' na trimester '.$trimester->label.' povazujeme za uhradenú. <br />
      S pozdravom, <br />
      Team BigHugGym.      
    </body>
    </html>      
    ';
    
    mail($kid->parrent->email,'Platba BigHugGym', $message, $headers);
    mail('kontrola.ruzinov@bighuggym.sk','ZALOHA: Platba BigHugGym', $message, $headers);
    
    $this->redirect(array('generatePayment'));
  
  }
  
  public function actionShowHour($date, $time){
    $time = str_replace('-', ':', $time);
    $data = Hours::model()->findAllByAttributes(array(
      'date'=>$date,
      'time_start'=>$time,
    ));
    $this->render('showHour', array('data'=>$data));    
  }  

  public function actionUpdateTimetable($id)
	{
		$model= Timetable::model()->findByPk($id);

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Timetable']))
		{
			$model->attributes=$_POST['Timetable'];
			if($model->save())
				$this->redirect(array('showTimetable'));
		}

		$this->render('updateTimetable',array(
			'model'=>$model,
		));
	}

	public function actionEnlistGenerate($tid)
	{
		$model=new Enlist;
    $enlisted = Enlist::model()->findAllByAttributes(array(
          'ID_timet'=> $tid,
        ));

        $klinks = array();
        foreach ($enlisted as $value) {
          $tkid = Kids::model()->findByPK($value->ID_kid);
          array_push($klinks, CHtml::link( $tkid->surname.' '.$tkid->name.'<br />', array('manager/dieta','id'=>$value->ID_kid), array('target'=>'_blank')));
          //$klinks = CHtml::link( $tkid->surname.' '.$tkid->name.'<br />', array('kids/view','id'=>$value->ID_kid));
        }  

		// Uncomment the following line if AJAX validation is needed
		// $this->performAjaxValidation($model);

		if(isset($_POST['Enlist']))
		{
			$model->attributes=$_POST['Enlist'];
			if($model->save())
				$this->redirect(array('enlistGenerate','tid'=>$tid));
		}

		$this->render('enlistGenerate', array(
			'model'=>$model, 
      'links'=>$klinks,
      'ttid'=>$tid,
		));
	}

  
}